@@ -12,11 +12,20 @@
 
 #include <string>
 
-#include "zmq.hpp"
 #include "xeus-zmq.hpp"
 
 namespace xeus
 {
+
+// Duplicate definition for cppzmq
+#if defined _WIN64
+    using fd_t = __int64;
+#elif defined _WIN32
+    using fd_t = unsinged int;
+#else
+    using fd_t = int;
+#endif
+
     XEUS_ZMQ_API
     std::string get_controller_end_point(const std::string& channel);
     
@@ -31,17 +40,6 @@ namespace xeus
     XEUS_ZMQ_API
     int get_socket_linger();
 
-    XEUS_ZMQ_API
-    void init_socket(zmq::socket_t& socket,
-                     const std::string& transport,
-                     const std::string& ip,
-                     const std::string& port);
-    XEUS_ZMQ_API
-    void init_socket(zmq::socket_t& socket, const std::string& end_point);
-
-    XEUS_ZMQ_API
-    std::string get_socket_port(const zmq::socket_t& socket);
-
     XEUS_ZMQ_API
     std::string find_free_port(std::size_t max_tries = 100, int start = 49152, int stop = 65536);
 }
